==> haskell-pager-0.1.1.0-187-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-SURXd9BAWu91vc9Esz908
key:                  pager-0.1.1.0-SURXd9BAWu91vc9Esz908
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  03d9b95db14a58db413f704147053ee7
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-SURXd9BAWu91vc9Esz908
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j directory-1.3.7.1
    process-1.6.18.0 resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP
    safe-0.3.21-FBimV6u2RMNDKpiH5qP0vN terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pager-0.1.1.0-206-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-DHed1VJ9ULJ1G0a7uZkTKl
key:                  pager-0.1.1.0-DHed1VJ9ULJ1G0a7uZkTKl
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  eb8e5ac00b59a5c31abd2c6189a181c1
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-DHed1VJ9ULJ1G0a7uZkTKl
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P directory-1.3.7.1
    process-1.6.18.0 resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl
    safe-0.3.21-JMKA2bKqr97GM6r3OADsOi terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
